NetworkService class

Constructors

NetworkService({required Dio dio, required String url})

Properties

dio → Dio
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
final

Methods

fetchMatchingPlaces() → Future<List<Place>?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited